@@ -156,12 +156,13 @@ class AsyncPopen(Popen):
         Called from the thread to update an input (stdin) queue.
         '''
         try:
-            lock.acquire()
-            while len(queue) > 0:
-                chunk = queue.popleft()
-                pipe.write(chunk)
-            lock.release()
-            pipe.flush()
+            while True:
+                lock.acquire()
+                while len(queue) > 0:
+                    chunk = queue.popleft()
+                    pipe.write(chunk)
+                lock.release()
+                pipe.flush()
         except:
             pass
         finally:
